@@ -552,6 +552,43 @@ enum ApiCallId : uint32_t
     ApiCall_vkSetDeviceMemoryPriorityEXT                                                          = MakeApiCallId(ApiFamily_Vulkan, 0x124a),
     ApiCall_vkCmdBeginRenderingKHR                                                                = MakeApiCallId(ApiFamily_Vulkan, 0x124b),
     ApiCall_vkCmdEndRenderingKHR                                                                  = MakeApiCallId(ApiFamily_Vulkan, 0x124c),
+    ApiCall_vkGetPhysicalDeviceToolProperties                                                     = MakeApiCallId(ApiFamily_Vulkan, 0x124d),
+    ApiCall_vkCreatePrivateDataSlot                                                               = MakeApiCallId(ApiFamily_Vulkan, 0x124e),
+    ApiCall_vkDestroyPrivateDataSlot                                                              = MakeApiCallId(ApiFamily_Vulkan, 0x124f),
+    ApiCall_vkSetPrivateData                                                                      = MakeApiCallId(ApiFamily_Vulkan, 0x1250),
+    ApiCall_vkGetPrivateData                                                                      = MakeApiCallId(ApiFamily_Vulkan, 0x1251),
+    ApiCall_vkCmdSetEvent2                                                                        = MakeApiCallId(ApiFamily_Vulkan, 0x1252),
+    ApiCall_vkCmdResetEvent2                                                                      = MakeApiCallId(ApiFamily_Vulkan, 0x1253),
+    ApiCall_vkCmdWaitEvents2                                                                      = MakeApiCallId(ApiFamily_Vulkan, 0x1254),
+    ApiCall_vkCmdPipelineBarrier2                                                                 = MakeApiCallId(ApiFamily_Vulkan, 0x1255),
+    ApiCall_vkCmdWriteTimestamp2                                                                  = MakeApiCallId(ApiFamily_Vulkan, 0x1256),
+    ApiCall_vkQueueSubmit2                                                                        = MakeApiCallId(ApiFamily_Vulkan, 0x1257),
+    ApiCall_vkCmdCopyBuffer2                                                                      = MakeApiCallId(ApiFamily_Vulkan, 0x1258),
+    ApiCall_vkCmdCopyImage2                                                                       = MakeApiCallId(ApiFamily_Vulkan, 0x1259),
+    ApiCall_vkCmdCopyBufferToImage2                                                               = MakeApiCallId(ApiFamily_Vulkan, 0x125a),
+    ApiCall_vkCmdCopyImageToBuffer2                                                               = MakeApiCallId(ApiFamily_Vulkan, 0x125b),
+    ApiCall_vkCmdBlitImage2                                                                       = MakeApiCallId(ApiFamily_Vulkan, 0x125c),
+    ApiCall_vkCmdResolveImage2                                                                    = MakeApiCallId(ApiFamily_Vulkan, 0x125d),
+    ApiCall_vkCmdBeginRendering                                                                   = MakeApiCallId(ApiFamily_Vulkan, 0x125e),
+    ApiCall_vkCmdEndRendering                                                                     = MakeApiCallId(ApiFamily_Vulkan, 0x125f),
+    ApiCall_vkCmdSetCullMode                                                                      = MakeApiCallId(ApiFamily_Vulkan, 0x1260),
+    ApiCall_vkCmdSetFrontFace                                                                     = MakeApiCallId(ApiFamily_Vulkan, 0x1261),
+    ApiCall_vkCmdSetPrimitiveTopology                                                             = MakeApiCallId(ApiFamily_Vulkan, 0x1262),
+    ApiCall_vkCmdSetViewportWithCount                                                             = MakeApiCallId(ApiFamily_Vulkan, 0x1263),
+    ApiCall_vkCmdSetScissorWithCount                                                              = MakeApiCallId(ApiFamily_Vulkan, 0x1264),
+    ApiCall_vkCmdBindVertexBuffers2                                                               = MakeApiCallId(ApiFamily_Vulkan, 0x1265),
+    ApiCall_vkCmdSetDepthTestEnable                                                               = MakeApiCallId(ApiFamily_Vulkan, 0x1266),
+    ApiCall_vkCmdSetDepthWriteEnable                                                              = MakeApiCallId(ApiFamily_Vulkan, 0x1267),
+    ApiCall_vkCmdSetDepthCompareOp                                                                = MakeApiCallId(ApiFamily_Vulkan, 0x1268),
+    ApiCall_vkCmdSetDepthBoundsTestEnable                                                         = MakeApiCallId(ApiFamily_Vulkan, 0x1269),
+    ApiCall_vkCmdSetStencilTestEnable                                                             = MakeApiCallId(ApiFamily_Vulkan, 0x126a),
+    ApiCall_vkCmdSetStencilOp                                                                     = MakeApiCallId(ApiFamily_Vulkan, 0x126b),
+    ApiCall_vkCmdSetRasterizerDiscardEnable                                                       = MakeApiCallId(ApiFamily_Vulkan, 0x126c),
+    ApiCall_vkCmdSetDepthBiasEnable                                                               = MakeApiCallId(ApiFamily_Vulkan, 0x126d),
+    ApiCall_vkCmdSetPrimitiveRestartEnable                                                        = MakeApiCallId(ApiFamily_Vulkan, 0x126e),
+    ApiCall_vkGetDeviceBufferMemoryRequirements                                                   = MakeApiCallId(ApiFamily_Vulkan, 0x126f),
+    ApiCall_vkGetDeviceImageMemoryRequirements                                                    = MakeApiCallId(ApiFamily_Vulkan, 0x1270),
+    ApiCall_vkGetDeviceImageSparseMemoryRequirements                                              = MakeApiCallId(ApiFamily_Vulkan, 0x1271),
 
     ApiCall_VulkanLast
     // clang-format on
